@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Lite;
 
-our $DATE = '2017-01-13'; # DATE
-our $VERSION = '1.71'; # VERSION
+our $DATE = '2017-01-16'; # DATE
+our $VERSION = '1.72'; # VERSION
 
 use 5.010001;
 # use strict; # already enabled by Mo
@@ -296,7 +296,7 @@ sub hook_format_result {
     }
 
     my $fres = Perinci::Result::Format::Lite::format(
-        $r->{res}, $fmt, $r->{naked_res});
+        $r->{res}, $fmt, $r->{naked_res}, $self->{use_cleanser});
 
     # ux: prefix error message with program name
     if ($fmt =~ /text/ && $r->{res}[0] =~ /\A[45]/ && defined($r->{res}[1])) {
@@ -523,7 +523,7 @@ Perinci::CmdLine::Lite - A Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.71 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2017-01-13.
+This document describes version 1.72 of Perinci::CmdLine::Lite (from Perl distribution Perinci-CmdLine-Lite), released on 2017-01-16.
 
 =head1 SYNOPSIS
 
